@@ -224,6 +224,9 @@ pub trait NumTools<T> {
     /// ```
     #[must_use = "This returns the result of the operation, without modifying the original."]
     fn cube(&self) -> Self;
+
+    #[must_use = "This returns the result of the operation, without modifying the original."]
+    fn recip(&self) -> Self;
 }
 
 impl<T: PartialOrd +
@@ -278,6 +281,11 @@ impl<T: PartialOrd +
     fn cube(&self) -> Self {
         *self * *self * *self
     }
+
+    #[inline]
+    fn recip(&self) -> Self {
+        Self::from(1u8) / *self
+    }
 }
 
 impl<'a, T: PartialEq +
@@ -516,6 +524,7 @@ pub fn euler_gamma<T: Into<f64>>(z: T, precision: f64) -> f64 {
 /// assert_eq!(gcd(3, 6), 3);
 /// assert_eq!(gcd(52, 345), 1);
 /// ```
+#[must_use]
 pub fn gcd<T: From<u8> +
               PartialEq +
               PartialOrd +
